@@ -10,15 +10,16 @@ import asyncio
 import logging
 import socket
 from sys import platform
+import time
 from typing import TYPE_CHECKING, Callable, Tuple, cast
 
 from xknx.exceptions import CommunicationError, CouldNotParseKNXIP, XKNXException
-from xknx.knxip import KNXIPFrame, KNXIPServiceType
+from xknx.knxip import HPAI, KNXIPFrame, KNXIPServiceType
 
 if TYPE_CHECKING:
     from xknx.xknx import XKNX
 
-    CallbackType = Callable[[KNXIPFrame, "UDPClient"], None]
+    CallbackType = Callable[[KNXIPFrame, HPAI, "UDPClient"], None]
 
 raw_socket_logger = logging.getLogger("xknx.raw_socket")
 logger = logging.getLogger("xknx.log")
@@ -51,7 +52,8 @@ class UDPClient:
             self,
             own_ip: str,
             multicast: bool = False,
-            data_received_callback: Callable[[bytes], None] | None = None,
+            data_received_callback: Callable[[bytes, tuple[str, int]], None]
+            | None = None,
         ):
             """Initialize UDPClientFactory class."""
             self.own_ip = own_ip
@@ -67,7 +69,7 @@ class UDPClient:
             """Call assigned callback. Callback for datagram received."""
             raw_socket_logger.debug("Received from %s: %s", addr, data.hex())
             if self.data_received_callback is not None:
-                self.data_received_callback(data)
+                self.data_received_callback(data, addr)
 
         def error_received(self, exc: Exception) -> None:
             """Call when a send or receive operation raises an OSError."""
@@ -97,7 +99,7 @@ class UDPClient:
 
         self.transport: asyncio.DatagramTransport | None = None
 
-    def data_received_callback(self, raw: bytes) -> None:
+    def data_received_callback(self, raw: bytes, source: tuple[str, int]) -> None:
         """Parse and process KNXIP frame. Callback for having received an UDP packet."""
         if raw:
             try:
@@ -105,24 +107,36 @@ class UDPClient:
                 knxipframe.from_knx(raw)
             except CouldNotParseKNXIP as couldnotparseknxip:
                 knx_logger.debug(
-                    "Unsupported KNXIPFrame: %s in %s",
+                    "Unsupported KNXIPFrame from %s:%s at %s: %s in %s",
+                    source[0],
+                    source[1],
+                    time.time(),
                     couldnotparseknxip.description,
                     raw.hex(),
                 )
             else:
-                knx_logger.debug("Received: %s", knxipframe)
-                self.handle_knxipframe(knxipframe)
+                knx_logger.debug(
+                    "Received from %s:%s at %s:\n%s",
+                    source[0],
+                    source[1],
+                    time.time(),
+                    knxipframe,
+                )
+                self.handle_knxipframe(knxipframe, HPAI(*source))
 
-    def handle_knxipframe(self, knxipframe: KNXIPFrame) -> None:
-        """Handle KNXIP Frame and call all callbacks which watch for the service type ident."""
+    def handle_knxipframe(self, knxipframe: KNXIPFrame, source: HPAI) -> None:
+        """Handle KNXIP Frame and call all callbacks matching the service type ident."""
         handled = False
         for callback in self.callbacks:
             if callback.has_service(knxipframe.header.service_type_ident):
-                callback.callback(knxipframe, self)
+                callback.callback(knxipframe, source, self)
                 handled = True
         if not handled:
             knx_logger.debug(
-                "Unhandled %s: %s", knxipframe.header.service_type_ident, knxipframe
+                "Unhandled %s: %s from: %s",
+                knxipframe.header.service_type_ident,
+                knxipframe,
+                source,
             )
 
     def register_callback(
@@ -145,7 +159,7 @@ class UDPClient:
     @staticmethod
     def create_multicast_sock(
         own_ip: str, remote_addr: tuple[str, int]
-    ) -> socket.SocketType:
+    ) -> socket.socket:
         """Create UDP multicast socket."""
         sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
@@ -206,7 +220,13 @@ class UDPClient:
 
     def send(self, knxipframe: KNXIPFrame) -> None:
         """Send KNXIPFrame to socket."""
-        knx_logger.debug("Sending: %s", knxipframe)
+        knx_logger.debug(
+            "Sending to %s:%s at %s:\n%s",
+            self.remote_addr[0],
+            self.remote_addr[1],
+            time.time(),
+            knxipframe,
+        )
         if self.transport is None:
             raise XKNXException("Transport not connected")
 
